@@ -24,6 +24,14 @@ test_that("describe_data_repository_tasks", {
   expect_error(svc$describe_data_repository_tasks(MaxResults = 20), NA)
 })
 
+test_that("describe_file_caches", {
+  expect_error(svc$describe_file_caches(), NA)
+})
+
+test_that("describe_file_caches", {
+  expect_error(svc$describe_file_caches(MaxResults = 20), NA)
+})
+
 test_that("describe_file_systems", {
   expect_error(svc$describe_file_systems(), NA)
 })
